#!/usr/bin/env python

import re
import os
import os.path
import sys

def process_scores(h_file):
    result_lines = []
    for line in h_file:
        # grep '^Ln Likelihood' $* /dev/null
        if re.search('^Ln Likelihood', line):
            # sed 's/^\([^:]*\):\(.*\)$/\2  (file: \1)/g'
            result_lines.append(re.sub("^([^:]*):(.*)$", "\2  (file: \1)", line))
    return result_lines

def traverse_directory(dir, prefix = None):
    result_lines = []
    for file in dir:
        # handle regular expressions
        if re.search("[\*\?\[]", file):
            file_pattern = re.sub("[\*\?]", ".\1", re.sub("\.", "\\.", file))
            if not prefix:
                if re.search("/", "", file_pattern):
                    prefix = os.path.dirname(file_pattern)
                else:
                    prefix = os.getcwd()
            traverse_directory([filename for filename in os.listdir(prefix) if (re.search(file_pattern))], prefix)
        # handle regular files and directories
        elif os.path.exists(file):
            # file encountered - base case
            if os.path.isfile(file):
                if prefix:
                    h_file = open(os.path.join(prefix, file), "r")
                else:
                    h_file = open(file, "r")
                result_lines += process_scores(h_file)
                h_file.close()
            # directory encountered - recursion
            elif os.path.isdir(file):
                traverse_directory(os.path.listdir(file), file)
    return result_lines


result_lines = []
if len(sys.argv) > 2:
    result_lines = traverse_directory(sys.argv[1:])
else:
    result_lines = process_scores(sys.stdin)
    
# sort -nr +3
# sort keys numerically in descending order from the 3rd column
try:
    sorted(result_lines, key=lambda ln: int(ln.split(" ")[2]))
except:
    True

for line in result_lines:
    sys.stdout.write(line)
